@@ -1,16 +1,28 @@
 import redis
-from redis.connection import ConnectionPool, PythonParser
+from redis.connection import PythonParser
 
 from config import CONFIG as cfg
 
 # Because of a bug (https://github.com/andymccurdy/redis-py/issues/318) with
 # script reloading in `redis-py, we need to force the `PythonParser` to prevent
 # sixpack from crashing if redis restarts (or scripts are flushed).
-pool = ConnectionPool(host=cfg.get('redis_host'),
-                      port=cfg.get('redis_port'),
-                      password=cfg.get('redis_password', None),
-                      db=cfg.get('redis_db'),
-                      parser_class=PythonParser)
+if cfg.get('redis_sentinels'):
+    from redis.sentinel import Sentinel, SentinelConnectionPool
+    service_name = cfg.get('redis_sentinel_service_name')
+    sentinel = Sentinel(sentinels=cfg.get('redis_sentinels'),
+                        password=cfg.get('redis_password', None),
+                        socket_timeout=cfg.get('redis_socket_timeout'))
+    pool = SentinelConnectionPool(service_name, sentinel,
+                                db=cfg.get('redis_db'),
+                                parser_class=PythonParser)
+else:
+    from redis.connection import ConnectionPool
+    pool = ConnectionPool(host=cfg.get('redis_host'),
+                        port=cfg.get('redis_port'),
+                        password=cfg.get('redis_password', None),
+                        db=cfg.get('redis_db'),
+                        parser_class=PythonParser)
+
 REDIS = redis.StrictRedis(connection_pool=pool)
 DEFAULT_PREFIX = cfg.get('redis_prefix')
 
